summary refs log tree commit diff
path: root/pkgs/development/compilers
diff options
context:
space:
mode:
authorMatthew Justin Bauer <mjbauer95@gmail.com>2018-04-09 14:25:38 -0500
committerGitHub <noreply@github.com>2018-04-09 14:25:38 -0500
commit0dd1bb1628e570331954462f3710f1e5a1d5d35e (patch)
tree8d4abe009a3e6f2183e7e1426c7cb20e2ab368ee /pkgs/development/compilers
parentdb8d8ac31e1b8fb74e13ea03f98914746c7b7227 (diff)
parentf2622e6aff3ff69557bd238ed6b0e9c941068884 (diff)
downloadnixlib-0dd1bb1628e570331954462f3710f1e5a1d5d35e.tar
nixlib-0dd1bb1628e570331954462f3710f1e5a1d5d35e.tar.gz
nixlib-0dd1bb1628e570331954462f3710f1e5a1d5d35e.tar.bz2
nixlib-0dd1bb1628e570331954462f3710f1e5a1d5d35e.tar.lz
nixlib-0dd1bb1628e570331954462f3710f1e5a1d5d35e.tar.xz
nixlib-0dd1bb1628e570331954462f3710f1e5a1d5d35e.tar.zst
nixlib-0dd1bb1628e570331954462f3710f1e5a1d5d35e.zip
Merge pull request #34318 from cumber/fix/mono-use-configure-flags
mono{48,50,54}: make sure configureFlags are used in configurePhase
Diffstat (limited to 'pkgs/development/compilers')
-rw-r--r--pkgs/development/compilers/mono/generic-cmake.nix10
1 files changed, 4 insertions, 6 deletions
diff --git a/pkgs/development/compilers/mono/generic-cmake.nix b/pkgs/development/compilers/mono/generic-cmake.nix
index 7621bd56d47b..929d00491382 100644
--- a/pkgs/development/compilers/mono/generic-cmake.nix
+++ b/pkgs/development/compilers/mono/generic-cmake.nix
@@ -23,8 +23,6 @@ stdenv.mkDerivation rec {
   # To overcome the bug https://bugzilla.novell.com/show_bug.cgi?id=644723
   dontDisableStatic = true;
 
-  # In fact I think this line does not help at all to what I
-  # wanted to achieve: have mono to find libgdiplus automatically
   configureFlags = [
     "--x-includes=${libX11.dev}/include"
     "--x-libraries=${libX11.out}/lib"
@@ -38,7 +36,7 @@ stdenv.mkDerivation rec {
 
   configurePhase = ''
     patchShebangs ./
-    ./autogen.sh --prefix $out
+    ./autogen.sh --prefix $out $configureFlags
   '';
 
   # Attempt to fix this error when running "mcs --version":
@@ -58,13 +56,13 @@ stdenv.mkDerivation rec {
     substituteInPlace mono/mini/aot-compiler.c --replace "llvm_path = g_strdup (\"\")" "llvm_path = g_strdup (\"${llvm}/bin/\")"
   '';
 
   # Fix mono DLLMap so it can find libX11 and gdiplus to run winforms apps
   # Other items in the DLLMap may need to be pointed to their store locations, I don't think this is exhaustive
   # http://www.mono-project.com/Config_DllMap
   postBuild = ''
     find . -name 'config' -type f | xargs \
-    sed -i -e "s@libX11.so.6@${libX11.out}/lib/libX11.so.6@g" \
-           -e 's#[^"]*libgdiplus[^"]*"#${libgdiplus}/lib/libgdiplus.so"#' \
+    sed -i -e "s@libX11.so.6@${libX11.out}/lib/libX11.so.6@g"
   '';
 
   # Without this, any Mono application attempting to open an SSL connection will throw with
@@ -58,13 +56,13 @@ stdenv.mkDerivation rec {
   '';
 
-  # Fix mono DLLMap so it can find libX11 and gdiplus to run winforms apps
+  # Fix mono DLLMap so it can find libX11 to run winforms apps
+  # libgdiplus is correctly handled by the --with-libgdiplus configure flag
   # Other items in the DLLMap may need to be pointed to their store locations, I don't think this is exhaustive
   # http://www.mono-project.com/Config_DllMap